import { Button } from '@/components/ui/button';
import {
    NavigationMenu,
    NavigationMenuContent,
    NavigationMenuItem,
    NavigationMenuList,
    NavigationMenuTrigger,
} from '@/components/ui/navigation-menu';
import { Link, usePage } from '@inertiajs/react';
import { Menu, X } from 'lucide-react';
import { useEffect, useState } from 'react';

const Navbar = () => {
    const [isScrolled, setIsScrolled] = useState(false);
    const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

    const { url } = usePage();

    useEffect(() => {
        const handleScroll = () => {
            if (window.scrollY > 50) {
                setIsScrolled(true);
            } else {
                setIsScrolled(false);
            }
        };

        window.addEventListener('scroll', handleScroll);
        return () => {
            window.removeEventListener('scroll', handleScroll);
        };
    }, []);

    const toggleMobileMenu = () => {
        setIsMobileMenuOpen(!isMobileMenuOpen);
    };

    return (
        <nav className={`bg-primary lg:fixed top-0 right-0 left-0 z-50 bg-white py-2 shadow-md transition-all duration-300`}>
            <div className="container mx-auto flex items-center justify-between px-4">
                <Link href="/" className={`flex items-center transition-transform duration-300 hover:scale-105`}>
                    <img src="/lovable-uploads/logo.png" alt="Green Isle Tours" className="mr-2 h-16" />
                </Link>

                {/* Desktop Navigation */}
                <div className="hidden md:flex items-center justify-between flex-1 ml-8">
                    {/* Left-aligned navigation items */}
                    <NavigationMenu>
                        <NavigationMenuList>
                            <NavigationMenuItem>
                                <NavigationMenuTrigger className={'text-gray-700'}>Travel Style</NavigationMenuTrigger>
                                <NavigationMenuContent>
                                    <ul className="grid w-[200px] gap-2 p-4">
                                        <li className="mb-2 font-semibold">Group Tours</li>
                                        <li>
                                            <Link href="/tour/classic-tour" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                Classic Tour
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/tour/18-40-tour" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                18 to 40's
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/tour/in-to-the-wilderness" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                In to the wilderness
                                            </Link>
                                        </li>
                                        <li className="mt-4 mb-2 font-semibold">Individual Tours</li>
                                        <li>
                                            <Link href="/tours" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                Culture Triangle
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/tours" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                Honeymoon
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/tours" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                Family tours
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/tours" className="block rounded-md p-2 hover:bg-[#92C743]/10">
                                                Hiking
                                            </Link>
                                        </li>
                                    </ul>
                                </NavigationMenuContent>
                            </NavigationMenuItem>

                            <NavigationMenuItem>
                                <NavigationMenuTrigger className={'text-gray-700'}>Pack & Plan</NavigationMenuTrigger>
                                <NavigationMenuContent>
                                    <ul className="grid w-[200px] gap-2 p-4">
                                        <li>
                                            <Link href="/packing-list" className="block rounded-md p-2 hover:bg-slate-100">
                                                Packing list
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/visa-information" className="block rounded-md p-2 hover:bg-slate-100">
                                                Visa Information
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/need-to-knows" className="block rounded-md p-2 hover:bg-slate-100">
                                                Need to Knows
                                            </Link>
                                        </li>
                                    </ul>
                                </NavigationMenuContent>
                            </NavigationMenuItem>

                            <NavigationMenuItem>
                                <NavigationMenuTrigger className={'text-gray-700'}>About Us</NavigationMenuTrigger>
                                <NavigationMenuContent>
                                    <ul className="grid w-[200px] gap-2 p-4">
                                        <li>
                                            <Link href="/about" className="block rounded-md p-2 hover:bg-slate-100">
                                                Meet Our Green Guides
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/history" className="block rounded-md p-2 hover:bg-slate-100">
                                                Our History
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/make-difference" className="block rounded-md p-2 hover:bg-slate-100">
                                                Make a Difference
                                            </Link>
                                        </li>
                                        <li>
                                            <Link href="/testimonials" className="block rounded-md p-2 hover:bg-slate-100">
                                                Reviews
                                            </Link>
                                        </li>
                                    </ul>
                                </NavigationMenuContent>
                            </NavigationMenuItem>

                            <NavigationMenuItem>
                                <Link href="/blog" className={`font-bold text-gray-700 transition-colors duration-300 hover:scale-105 navFont uppercase`}>
                                    <span className="p-2 font-bold">Blog</span>
                                </Link>
                            </NavigationMenuItem>
                        </NavigationMenuList>
                    </NavigationMenu>

                    {/* Right-aligned contact us */}
                    <div className="ml-auto">
                        <Link href="/contact" className={`font-bold text-gray-700 transition-colors duration-300 hover:scale-105 navFont uppercase`}>
                            <span className="p-2 font-bold">Contact Us</span>
                        </Link>
                    </div>
                </div>

                {/* Mobile menu button */}
                <div className="md:hidden">
                    <button onClick={toggleMobileMenu} className={`p-2 text-[#92C743] focus:outline-none`}>
                        {isMobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
                    </button>
                </div>
            </div>

            {/* Mobile menu */}
            {isMobileMenuOpen && (
                <div className="animate-fade-in bg-white px-4 py-4 shadow-lg md:hidden">
                    <div className="flex flex-col space-y-4">
                        <div className="space-y-2">
                            <div className="font-medium">Travel Style</div>
                            <div className="space-y-2 pl-4">
                                <div className="text-sm font-medium text-gray-600">Group Tours</div>
                                <Link href="/tour/classic-tour" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    Classic Tour
                                </Link>
                                <Link href="/tour/18-40-tour" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    18 to 40's
                                </Link>
                                <Link href="/tour/in-to-the-wilderness" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    In to the wilderness
                                </Link>
                            </div>
                            <div className="space-y-2 pl-4">
                                <div className="text-sm font-medium text-gray-600">Individual Tours</div>
                                <Link href="/tours" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    Culture Triangle
                                </Link>
                                <Link href="/tours" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    Honeymoon
                                </Link>
                                <Link href="/tours" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    Family tours
                                </Link>
                                <Link href="/tours" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                    Hiking
                                </Link>
                            </div>
                        </div>

                        <div className="space-y-2">
                            <div className="font-medium">Pack & Plan</div>
                            <Link href="/packing-list" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Packing list
                            </Link>
                            <Link href="/visa-information" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Visa Information
                            </Link>
                            <Link href="/need-to-knows" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Need to Knows
                            </Link>
                        </div>

                        <div className="space-y-2">
                            <div className="font-medium">About Us</div>
                            <Link href="/about" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Meet Our Green Guides
                            </Link>
                            <Link href="/history" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Our History
                            </Link>
                            <Link href="/make-difference" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Make a Difference
                            </Link>
                            <Link href="/testimonials" className="hover:text-secondary block py-1 pl-4 text-gray-700" onClick={toggleMobileMenu}>
                                Reviews
                            </Link>
                        </div>

                        <Link href="/blog" className="hover:text-secondary font-medium text-gray-700" onClick={toggleMobileMenu}>
                            Blog
                        </Link>
                        <Link href="/contact" className="hover:text-secondary font-medium text-gray-700" onClick={toggleMobileMenu}>
                            Contact Us
                        </Link>

                        <Button variant="default" className="w-full rounded-full bg-[#92C743] text-white hover:bg-[#92C743]/90">
                            Book Now
                        </Button>
                    </div>
                </div>
            )}
        </nav>
    );
};

export default Navbar;